@@ -972,12 +972,15 @@ class AppGui:
         self.etimestamp.focus_set()
 
 # Main application
+def main():
+    appwin = Tk()
+    appwin.title("AutoCoconut - a workflow tracking tool.")
+    appwin.minsize(width=1024, height=550)
+    appwin.resizable(False, False)
+    
+    appgui = AppGui(appwin)
+    
+    appwin.mainloop()
 
-appwin = Tk()
-appwin.title("AutoCoconut - a workflow tracking tool.")
-appwin.minsize(width=1024, height=550)
-appwin.resizable(False, False)
-
-appgui = AppGui(appwin)
-
-appwin.mainloop()
+if __name__ == "__main__":
+    main()
