@@ -471,15 +471,27 @@ class Interpreter:
                 else:
                     self.use_buffer(addition=" ")
             # If the key is a tab, we will not record it in the text buffer, but rather handle it as a
-            # special key.
+            # special key. However, this is only true, if tab is not modified. FIXME
             elif event['key'] == "tab":
-                # It means we need to collect a previously typed text
-                leftover = self.deal_with_key_leftovers("typing", "tab pressed")
-                output.update(leftover)
-                # and remember this tab event
-                output[timestamp] = event
-                self.last_alpha_event = event
-                self.last_key_timestamp = None
+                if not self.modified:
+                    # It means we need to collect a previously typed text
+                    leftover = self.deal_with_key_leftovers("typing", "tab pressed")
+                    output.update(leftover)
+                    # and remember this tab event
+                    output[timestamp] = event
+                    self.last_alpha_event = event
+                    self.last_key_timestamp = None
+                else:
+                    leftover = self.deal_with_key_leftovers("typing", "special key pressed")
+                    output.update(leftover)
+                    event['reason'] = "key released"
+                    event['type'] = "key combination"
+                    event['subtype'] = "modifier"
+                    event['combined'] = self.modified
+                    self.last_mod_event = None
+                    self.last_special_event = event
+                    output[timestamp] = event
+                    
             # Sometimes, the key input is not recognized properly and None is returned instead
             # of the proper key name. On my system, there are two cases that produce this, such as
             # the 'right alt' key and the 'numeric 5'. While we might be able to workaround the
